==> gswidgetkit-0.2.5.tar.gz: gswidgetkit-0.2.5/README.md <==
#   g s w i d g e t k i t 
 
 
 
 V a r i o u s   c u s t o m   w i d g e t s   f o r   w x p y t h o n ,   c r e a t e d   t o   b e   u s e d   i n   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o ) . 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   l o o k   a n d   f u n c t i o n a l i t y   o f   B l e n d e r   a n d   S k e t c h   w i d g e t s .   * C u r r e n t l y ,   i t   u s e s   s t y l e s   s p e c i f i c   t o   G i m e l   S t u d i o ,   b u t   t h e y   c a n   b e   c u s t o m i z e d   a s   y o u   l i k e   i n   ` ` c o n s t a n t s . p y ` ` . * 
 
 
 
 
 
 # #   W i d g e t   C o n t e n t s 
 
 
 
 -   [ x ]   B u t t o n s   ( w i t h   t e x t   +   i c o n   o r   j u s t   i c o n ) 
 
 -   [ x ]   N u m b e r   F i e l d   ( s i m i l a r   t o   B l e n d e r ' s   N u m b e r   F i e l d   c o n t r o l ) 
 
 -   [ x ]   C o l o r   P i c k e r 
 
 -   [ x ]   T e x t c t r l 
 
 -   [ x ]   C h e c k b o x 
 
 -   [ x ]   T o o l t i p 
 
 -   [ x ]   S t a t i c   L a b e l 
 
 -   [ x ]   D r o p d o w n   ( s t i l l   n e e d s   w o r k ) 
 
 -   [   ]   I m a g e   P i c k e r 
 
 -   [   ]   R a d i o   B u t t o n s 
 
 -   [   ]   S c r o l l b a r 
 
 
 
 
 
 # #   G e t   S t a r t e d 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s w i d g e t k i t ` ` `   a n d   r u n   t h e   ` ` ` d e m o . p y ` ` `   f i l e   f r o m   t h i s   r e p o s i t o r y   f o r   a   d e m o   o f   t h e   w i d g e t s . 
 
 
 
 
 
 # #   C o n t r i b u t i n g 
 
 
 
 A l l   c o n t r i b u t i o n s   a r e   w e l c o m e !   S e e   [ C O N T R I B U T I N G . m d ] ( C O N T R I B U T I N G . m d )   f o r   d e t a i l s .   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s . 
 
 
 
 
 
 # #   R e l e a s i n g   o n   P y P I 
 
 
 
 N a v i g a t e   t o   t h e   r o o t   d i r e c t o r y 
 
 
 
 R u n   ` ` p y   - m   b u i l d ` ` 
 
 
 
 T h e n   r u n   ` ` t w i n e   u p l o a d   d i s t / * ` `   a n d   f o l l o w   t h e   p r o m p t s . 
 
 
 
 
 
 # #   L i c e n s e 
 
 
 
 L i c e n s e d   u n d e r   t h e   A p a c h e   2 . 0   L i c e n s e .   F e e l   f r e e   t o   u s e   t h e s e   w i d g e t s   a s   a   s t a r t i n g   p o i n t ,   e t c   f o r   y o u r   o w n   p r o j e c t s . 
 
 

==> gswidgetkit-0.3.3.tar.gz: gswidgetkit-0.3.3/README.md <==
#   g s w i d g e t k i t 
 
 
 
 V a r i o u s   c u s t o m   w i d g e t s   f o r   w x P y t h o n ,   c r e a t e d   t o   b e   u s e d   i n   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o ) . 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   l o o k   a n d   f u n c t i o n a l i t y   o f   B l e n d e r   a n d   S k e t c h   w i d g e t s .   * C u r r e n t l y ,   i t   u s e s   s t y l e s   s p e c i f i c   t o   G i m e l   S t u d i o ,   b u t   t h e y   c a n   b e   c u s t o m i z e d   a s   y o u   l i k e   i n   ` ` c o n s t a n t s . p y ` ` . * 
 
 
 
 
 
 # #   W i d g e t   C o n t e n t s 
 
 
 
 -   [ x ]   B u t t o n s   ( w i t h   t e x t   +   i c o n   o r   j u s t   i c o n ) 
 
 -   [ x ]   N u m b e r   F i e l d   s u p p o r t i n g   i n t e g e r s   a n d   f l o a t s   ( s i m i l a r   t o   B l e n d e r ' s   N u m b e r   F i e l d   c o n t r o l ) 
 
 -   [ x ]   C o l o r   P i c k e r 
 
 -   [ x ]   T e x t c t r l 
 
 -   [ x ]   C h e c k b o x 
 
 -   [ x ]   T o o l t i p 
 
 -   [ x ]   S t a t i c   L a b e l 
 
 -   [ x ]   D r o p d o w n   ( s t i l l   n e e d s   w o r k ) 
 
 -   [   ]   C o l o r   P i c k e r   P o p u p 
 
 -   [   ]   I m a g e   P i c k e r 
 
 -   [   ]   R a d i o   B u t t o n s 
 
 -   [   ]   S c r o l l b a r 
 
 
 
 
 
 # #   G e t   S t a r t e d 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s w i d g e t k i t ` ` `   a n d   r u n   t h e   ` ` ` d e m o . p y ` ` `   f i l e   f r o m   t h i s   r e p o s i t o r y   f o r   a   d e m o   o f   t h e   w i d g e t s . 
 
 
 
 
 
 # #   C o n t r i b u t i n g 
 
 
 
 A l l   c o n t r i b u t i o n s   a r e   w e l c o m e !   S e e   [ C O N T R I B U T I N G . m d ] ( C O N T R I B U T I N G . m d )   f o r   d e t a i l s .   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s . 
 
 
 
 
 
 # #   R e l e a s i n g   o n   P y P I 
 
 
 
 N a v i g a t e   t o   t h e   r o o t   d i r e c t o r y 
 
 
 
 R u n   ` ` p y   - m   b u i l d ` ` 
 
 
 
 T h e n   r u n   ` ` t w i n e   u p l o a d   d i s t / * ` `   a n d   f o l l o w   t h e   p r o m p t s . 
 
 
 
 
 
 # #   L i c e n s e 
 
 
 
 L i c e n s e d   u n d e r   t h e   A p a c h e   2 . 0   L i c e n s e .   F e e l   f r e e   t o   u s e   t h e s e   w i d g e t s   a s   a   s t a r t i n g   p o i n t ,   e t c   f o r   y o u r   o w n   p r o j e c t s . 
 
 
